import { useState } from "react";

export const useForm = initialValues => {
	const [form, setFormProp] = useState(initialValues);

	const validator = (rules, value, allForm) => {
		const { requred, minL, match } = rules;

		let valid = true;
		if (requred) {
			valid = value.trim() !== "" && valid;
		}

		if (minL) {
			valid = value.trim().length < minL && valid;
		}
		if (match) {
			valid = value.trim() !== allForm[match] && valid;
		}

		return valid;
	};

	const onChangeHandler = e => {
		const { name, value } = e.target;

		setFormProp(prevState => {
			const values = Object.keys(prevState.form).reduce((prev, elem) => {
				if (elem === name) return prev.concat(value);
				return prev.concat(prevState.form[elem].value);
			}, []);

			return {
				...prevState,
				form: {
					...prevState.form,
					[name]: {
						...prevState.form[name],
						value
					}
				},
				validForm: values.some(value => value)
			};
		});
	};

	const focusEvent = e => {
		const { name } = e.target;

		setFormProp(prevState => ({
			...prevState,
			form: {
				...prevState.form,
				[name]: {
					...prevState.form[name],
					touch: true
				}
			}
		}));
	};

	const blurEvent = e => {
		const { name, value } = e.target;

		const prevValues = Object.keys(form.form).reduce((prev, elem) => {
			return { ...prev, [elem]: elem === name ? value : form.form[elem].value };
		}, {});

		setFormProp(prevState => {
			const lll = validator(prevState.form[name].validation, value, prevValues);
			console.log("lll", lll);
			return {
				...prevState,
				form: {
					...prevState.form,
					[name]: {
						...prevState.form[name],
						fail: value ? lll : true
					}
				}
			};
		});
	};

	const returnAllValues = () => {
		return Object.keys(form.form).reduce((prev, elem) => {
			return { ...prev, [elem]: form.form[elem].value };
		}, {});
	};

	return [form, { onChangeHandler, returnAllValues, focusEvent, blurEvent }];
};
